Disperser
=========

Base Classes and Calibration Tokens
-------------------------------------

.. automodule:: unite.disperser.base
   :members:
   :undoc-members:
   :show-inheritance:

Disperser Configuration
------------------------

.. automodule:: unite.disperser.config
   :members:
   :undoc-members:
   :show-inheritance:

Generic Dispersers
------------------

.. automodule:: unite.disperser.generic
   :members:
   :undoc-members:
   :show-inheritance:
